#-----------------------------------------------------------------------------
#-----------------------------------------------------------------------------
# Hallway helper for Ernyoka's Hallway prop
# Install in same folder with the props.
# Run the script to add a segment of hallway, with doors and lamp.
# The first run installs the hallway itself with one pair of doors
# and one lamp; subsequent runs will extend the hallway and add doors and lamp.
#-----------------------------------------------------------------------------
# June 15, 2004
# Copyright (c) 2004, David G. Drumright (aka ockham)
#-----------------------------------------------------------------------------

import poser
import string
import os
import sys
Zdif=1.213
Xdif=1.712

# Locate the script so we can find the door and lamp props
MyDir=sys.path[-1]
BaseDir=os.path.normpath(MyDir)
HallName=os.path.normpath(BaseDir + '/Hallway.pp2')
DoorName=os.path.normpath(BaseDir + '/HallwayDoor.pp2')
LampName=os.path.normpath(BaseDir + '/HallwayLamp.pp2')

scene = poser.Scene()

HallHere=0
# Locate the hallway, if not already present.
for OneActor in scene.Actors():
    Name=OneActor.Name()
    if string.count(Name,'Hallway'):
        HallHere=1
        # Force the CurrentActor to be the hall:
        scene.SelectActor(OneActor)
        # Change its Ztran and Zscale only if it's not brand new:
        HallZscale=HallProp.ParameterByCode(poser.kParmCodeZSCALE)
        HallZscale.SetValue(HallZscale.Value()+1.0)
        HallZtran=HallProp.ParameterByCode(poser.kParmCodeZTRAN)
        HallZtran.SetValue(HallZtran.Value()-1.213)
        break

if not HallHere:
    try:
        scene.LoadLibraryProp(HallName)
    except:
        raise "Hallway not in same directory with script."

HallProp = scene.CurrentActor()

# Use the new (or original) Zscale to set the Zdif for the other parts.
HallZscale=HallProp.ParameterByCode(poser.kParmCodeZSCALE)
Zdif=1.213 * 2.0 * (HallZscale.Value()-1.0)

# Add a lamp at the new Ztran:
try:
    scene.LoadLibraryProp(LampName)
except:
    raise "Lamp not in same directory with script."
LampActor=scene.CurrentActor()
LampZtran=LampActor.ParameterByCode(poser.kParmCodeZTRAN)
LampZtran.SetValue(LampZtran.Value()-Zdif)

# Add a left door at the new Ztran:
try:
    scene.LoadLibraryProp(DoorName)
except:
    raise "Lamp not in same directory with script."
DoorProp=scene.CurrentActor()
DoorZtran=DoorProp.ParameterByCode(poser.kParmCodeZTRAN)
DoorZtran.SetValue(DoorZtran.Value()-Zdif)

# Add a right door at the new Ztran: (no need to check now)
scene.LoadLibraryProp(DoorName)
DoorProp=scene.CurrentActor()
DoorZtran=DoorProp.ParameterByCode(poser.kParmCodeZTRAN)
DoorZtran.SetValue(DoorZtran.Value()-Zdif)
DoorYrot=DoorProp.ParameterByCode(poser.kParmCodeYROT)
DoorYrot.SetValue(180.0)
DoorXtran=DoorProp.ParameterByCode(poser.kParmCodeXTRAN)
DoorXtran.SetValue(DoorXtran.Value() + Xdif)


